@@ -6,10 +6,8 @@ pub mod alert_event_type_enum;
 pub use self::alert_event_type_enum::AlertEventTypeEnum;
 pub mod alert_request;
 pub use self::alert_request::AlertRequest;
-pub mod ansible_facts;
-pub use self::ansible_facts::AnsibleFacts;
-pub mod ansible_facts_request;
-pub use self::ansible_facts_request::AnsibleFactsRequest;
+pub mod ansible_state_enum;
+pub use self::ansible_state_enum::AnsibleStateEnum;
 pub mod artifact_types_enum;
 pub use self::artifact_types_enum::ArtifactTypesEnum;
 pub mod callback_token_auth_request;
@@ -30,6 +28,14 @@ pub mod cloudiot_device_request;
 pub use self::cloudiot_device_request::CloudiotDeviceRequest;
 pub mod command_enum;
 pub use self::command_enum::CommandEnum;
+pub mod current_state;
+pub use self::current_state::CurrentState;
+pub mod current_state_request;
+pub use self::current_state_request::CurrentStateRequest;
+pub mod desired_config;
+pub use self::desired_config::DesiredConfig;
+pub mod desired_config_request;
+pub use self::desired_config_request::DesiredConfigRequest;
 pub mod detail_response;
 pub use self::detail_response::DetailResponse;
 pub mod device;
@@ -120,12 +126,14 @@ pub mod octoprint_python_request;
 pub use self::octoprint_python_request::OctoprintPythonRequest;
 pub mod paginated_alert_list;
 pub use self::paginated_alert_list::PaginatedAlertList;
-pub mod paginated_ansible_facts_list;
-pub use self::paginated_ansible_facts_list::PaginatedAnsibleFactsList;
 pub mod paginated_camera_list;
 pub use self::paginated_camera_list::PaginatedCameraList;
 pub mod paginated_cloudiot_device_list;
 pub use self::paginated_cloudiot_device_list::PaginatedCloudiotDeviceList;
+pub mod paginated_current_state_list;
+pub use self::paginated_current_state_list::PaginatedCurrentStateList;
+pub mod paginated_desired_config_list;
+pub use self::paginated_desired_config_list::PaginatedDesiredConfigList;
 pub mod paginated_device_calibration_list;
 pub use self::paginated_device_calibration_list::PaginatedDeviceCalibrationList;
 pub mod paginated_device_list;
@@ -170,8 +178,6 @@ pub mod patched_alert_bulk_request_request;
 pub use self::patched_alert_bulk_request_request::PatchedAlertBulkRequestRequest;
 pub mod patched_alert_request;
 pub use self::patched_alert_request::PatchedAlertRequest;
-pub mod patched_ansible_facts_request;
-pub use self::patched_ansible_facts_request::PatchedAnsibleFactsRequest;
 pub mod patched_camera_request;
 pub use self::patched_camera_request::PatchedCameraRequest;
 pub mod patched_cloudiot_device_request;
